@@ -2,36 +2,28 @@
 
 #pragma once
 
-#include "zeek/zeek-config.h"
-
 #include <optional>
 #include <string>
 
-namespace zeek
-	{
+namespace zeek {
 
 class Packet;
 
-namespace iosource
-	{
+namespace iosource {
 
 class IOSource;
 class PktSrc;
 class PktDumper;
 
-	} // namespace iosource
+} // namespace iosource
 
-namespace run_state
-	{
-namespace detail
-	{
+namespace run_state {
+namespace detail {
 
-extern void init_run(const std::optional<std::string>& interfaces,
-                     const std::optional<std::string>& pcap_input_file,
+extern void init_run(const std::optional<std::string>& interfaces, const std::optional<std::string>& pcap_input_file,
                      const std::optional<std::string>& pcap_output_file, bool do_watchdog);
 extern void run_loop();
 extern void get_final_stats();
-extern void finish_run(int drain_events);
 extern void delete_run(); // Reclaim all memory, etc.
 extern void update_network_time(double new_network_time);
 extern void dispatch_packet(zeek::Packet* pkt, zeek::iosource::PktSrc* pkt_src);
@@ -67,7 +59,7 @@ extern bool zeek_init_done;
 
 extern bool bare_mode; // True if Zeek was started in bare mode.
 
-	} // namespace detail
+} // namespace detail
 
 // Functions to temporarily suspend processing of live input (network packets
 // and remote events/state). Turning this is on is sure to lead to data loss!
@@ -75,6 +67,7 @@ extern void suspend_processing();
 extern void continue_processing();
 bool is_processing_suspended();
 
+[[deprecated("Remove with v8.1. Use run_state::current_pseudo directly if needed.")]]
 extern double current_packet_timestamp();
 extern double current_packet_wallclock();
 
@@ -115,5 +108,5 @@ extern const zeek::Packet* current_pkt;
 extern int current_dispatched;
 extern double current_timestamp;
 
-	} // namespace run_state
-	} // namespace zeek
+} // namespace run_state
+} // namespace zeek
