@@ -250,7 +250,7 @@
 /* #undef ENABLE_SPICY_SSL */
 
 /* String with host architecture (e.g., "linux-x86_64") */
-#define HOST_ARCHITECTURE "openbsd-riscv64"
+#define HOST_ARCHITECTURE "openbsd-arm64"
 
 /* String with extension of dynamic libraries (e.g., ".so") */
 #define DYNAMIC_PLUGIN_SUFFIX ".so"
