@@ -2,19 +2,15 @@
 
 #pragma once
 
-#include "zeek/zeek-config.h"
-
-#include <time.h> // for time_t
+#include <ctime> // for time_t
 #include <optional>
 #include <string>
 
-namespace zeek::detail
-	{
+namespace zeek::detail {
 class ID;
-	}
+}
 
-namespace zeek::zeekygen::detail
-	{
+namespace zeek::zeekygen::detail {
 
 /**
  * Transform content of a Zeekygen comment which may contain function
@@ -93,4 +89,4 @@ std::string normalize_script_path(std::string_view path);
  */
 std::optional<std::string> source_code_range(const zeek::detail::ID* id);
 
-	} // namespace zeek::zeekygen::detail
+} // namespace zeek::zeekygen::detail
