@@ -2,11 +2,12 @@
 # One ZeekControl node.
 #
 
-import os
 import copy
+import os
 
 from ZeekControl import doc
 
+
 class Node:
     """Class representing one node of the ZeekControl maintained setup. In
     standalone mode, there's always exactly one node of type ``standalone``. In
@@ -102,11 +103,21 @@ class Node:
 
     # Valid keys in nodes file. The values will be stored in attributes of the
     # same name. Custom keys can be add via addKey().
-    _keys = {"type": 1, "host": 1, "interface": 1, "aux_scripts": 1,
-             "zeekbase": 1, "ether": 1, "zone_id": 1,
-             "lb_procs": 1, "lb_method": 1, "lb_interfaces": 1,
-             "pin_cpus": 1, "env_vars": 1, "count": 1}
-
+    _keys = {
+        "type": 1,
+        "host": 1,
+        "interface": 1,
+        "aux_scripts": 1,
+        "zeekbase": 1,
+        "ether": 1,
+        "zone_id": 1,
+        "lb_procs": 1,
+        "lb_method": 1,
+        "lb_interfaces": 1,
+        "pin_cpus": 1,
+        "env_vars": 1,
+        "count": 1,
+    }
 
     def __init__(self, config, name):
         """Instantiates a new node of the given name."""
@@ -119,6 +130,9 @@ class Node:
     def __str__(self):
         return self.name
 
+    def __format__(self, format_str):
+        return format(self.name, format_str)
+
     def copy(self):
         n = Node(self._config, self.name)
 
@@ -138,7 +152,7 @@ class Node:
 
         def tostr(v):
             if isinstance(v, dict):
-                return ",".join(["%s=%s" % (key, val) for (key, val) in sorted(v.items())])
+                return ",".join([f"{key}={val}" for (key, val) in sorted(v.items())])
             else:
                 return str(v)
 
@@ -153,13 +167,19 @@ class Node:
             if isinstance(v, list):
                 v = ",".join(v)
             elif isinstance(v, dict):
-                v = ",".join(["%s=%s" % (key, val) for (key, val) in sorted(v.items())])
+                v = ",".join([f"{key}={val}" for (key, val) in sorted(v.items())])
 
             return v
 
         # Do not output attributes starting with underscore, because they are
         # for internal use and don't provide useful information to the user.
-        return ("%16s - " % self.name) + " ".join(["%s=%s" % (k, fmt(self.__dict__[k])) for k in sorted(self.__dict__.keys()) if not k.startswith("_")])
+        return f"{self.name:>16s} - " + " ".join(
+            [
+                f"{k}={fmt(self.__dict__[k])}"
+                for k in sorted(self.__dict__.keys())
+                if not k.startswith("_")
+            ]
+        )
 
     def to_dict(self):
         d = dict(self.items())
@@ -174,39 +194,39 @@ class Node:
 
     def setPID(self, pid):
         """Stores the process ID of the node's Zeek process."""
-        key = "%s-pid" % self.name
+        key = f"{self.name}-pid"
         self._config.set_state(key, pid)
-        key = "%s-host" % self.name
+        key = f"{self.name}-host"
         self._config.set_state(key, self.host)
 
     @doc.api
     def getPID(self):
         """Returns the process ID of the node's Zeek process if running, and
         None otherwise."""
-        key = "%s-pid" % self.name
+        key = f"{self.name}-pid"
         return self._config.get_state(key)
 
     def clearPID(self):
         """Clears the stored process ID for the node's Zeek process, indicating
         that it is no longer running."""
-        key = "%s-pid" % self.name
+        key = f"{self.name}-pid"
         self._config.set_state(key, None)
 
     def setCrashed(self):
         """Marks node's Zeek process as having terminated unexpectedly."""
-        key = "%s-crashed" % self.name
+        key = f"{self.name}-crashed"
         self._config.set_state(key, True)
 
     def clearCrashed(self):
         """Clears the mark for the node's Zeek process having terminated
         unexpectedly."""
-        key = "%s-crashed" % self.name
+        key = f"{self.name}-crashed"
         self._config.set_state(key, False)
 
     @doc.api
     def hasCrashed(self):
         """Returns True if the node's Zeek process has exited abnormally."""
-        key = "%s-crashed" % self.name
+        key = f"{self.name}-crashed"
         val = self._config.get_state(key)
         if val is None:
             val = False
@@ -214,19 +234,19 @@ class Node:
 
     def getExpectRunning(self):
         """Returns True if we expect the node's Zeek process to be running."""
-        key = "%s-expect-running" % self.name
+        key = f"{self.name}-expect-running"
         val = self._config.get_state(key)
         if val is None:
             val = False
         return val
 
     def setExpectRunning(self, val):
-        key = "%s-expect-running" % self.name
+        key = f"{self.name}-expect-running"
         self._config.set_state(key, val)
 
     def setPort(self, port):
         """Set the Zeek port this node is using."""
-        key = "%s-port" % self.name
+        key = f"{self.name}-port"
         self._config.set_state(key, port)
 
     @doc.api
@@ -235,7 +255,7 @@ class Node:
         communication system is listening on for incoming connections, or -1 if
         no such port has been set yet.
         """
-        key = "%s-port" % self.name
+        key = f"{self.name}-port"
         return self._config.get_state(key) or -1
 
     @staticmethod
@@ -253,6 +273,7 @@ class Node:
 # use alphabetical order).
 _typeorder = ("standalone", "logger", "manager", "proxy", "worker")
 
+
 # Sorting key function for a list of nodes.
 def sortnode(n):
     try:
@@ -260,6 +281,7 @@ def sortnode(n):
     except ValueError:
         return len(_typeorder), n.count
 
+
 # Sorting key function for a list of tuples, where the first tuple element is
 # a node.
 def sorttuple(t):
@@ -269,6 +291,7 @@ def sorttuple(t):
     except ValueError:
         return len(_typeorder), n.count
 
+
 # Given a list of nodes (all of the same type), return a string that describes
 # the list of nodes (in either singular or plural form).  This string is
 # just for informational output, and doesn't have any other use or meaning.
@@ -287,26 +310,33 @@ def nodes_describe(nodes):
     elif nodetype == "worker":
         return "worker%s" % ("" if len(nodes) == 1 else "s")
 
+
 # Return a list of all node types.
 def node_types():
     return ["logger", "manager", "proxy", "worker", "standalone"]
 
+
 # Check if the given node is a certain type.
 def is_standalone(n):
     return n.type == "standalone"
 
+
 def is_manager(n):
     return n.type == "manager"
 
+
 def is_logger(n):
     return n.type == "logger"
 
+
 def is_proxy(n):
     return n.type == "proxy"
 
+
 def is_worker(n):
     return n.type == "worker"
 
+
 # Given a list of nodes, return separate lists for each type of node.
 def separate_types(nodes):
     loggers = []
@@ -326,34 +356,43 @@ def separate_types(nodes):
 
     return loggers, manager, proxies, workers
 
+
 # Map of node groups to node types (here, "_ALL_" is for internal use only and
 # matches all node types).
-grouptype = {"all": "_ALL_",
-             "loggers": "logger",
-             "manager": "manager",
-             "proxies": "proxy",
-             "workers": "worker"}
+grouptype = {
+    "all": "_ALL_",
+    "loggers": "logger",
+    "manager": "manager",
+    "proxies": "proxy",
+    "workers": "worker",
+}
+
 
 # Return a list of all node groups.  These are for convenience when using
 # zeekctl commands (e.g. "zeekctl start workers").
 def node_groups():
     return list(grouptype.keys())
 
+
 # Return the node type (or "_ALL_", which matches all node types) of a
 # specified group name.  If the "tag" doesn't match any group name, then None
 # is returned.
 def group_type(tag):
     return grouptype.get(tag)
 
+
 # Return the name of a node group.
 def manager_group():
     return "manager"
 
+
 def logger_group():
     return "loggers"
 
+
 def proxy_group():
     return "proxies"
 
+
 def worker_group():
     return "workers"
